@@ -16,6 +16,7 @@ from oauthlib.common import to_unicode, PY3, add_params_to_uri
 from flask import request, redirect, json, session, current_app
 from werkzeug import url_quote, url_decode, url_encode
 from werkzeug import parse_options_header, cached_property
+from .utils import to_bytes
 try:
     from urlparse import urljoin
     import urllib2 as http
@@ -433,14 +434,19 @@ class OAuthRemoteApp(object):
             uri, headers, body = self.pre_request(uri, headers, body)
 
         resp, content = self.http_request(
-            uri, headers, data=body, method=method
+            uri, headers, data=to_bytes(body, self.encoding), method=method
         )
         return OAuthResponse(resp, content, self.content_type)
 
-    def authorize(self, callback=None):
+    def authorize(self, callback=None, state=None):
         """
         Returns a redirect response to the remote authorization URL with
         the signed callback given.
+
+        :param callback: a redirect url for the callback
+        :param state: an optional value to embed in the OAuth request.
+                      Use this if you want to pass around application
+                      state (e.g. CSRF tokens).
         """
         if self.request_token_url:
             token = self.generate_request_token(callback)[0]
@@ -462,11 +468,23 @@ class OAuthRemoteApp(object):
                 # oauthlib need unicode
                 scope = _encode(scope, self.encoding)
 
+            if 'state' in params:
+                if not state:
+                    state = params.pop('state')
+                else:
+                    # remove state in params
+                    params.pop('state')
+
+            if callable(state):
+                # state can be function for generate a random string
+                state = state()
+
             session['%s_oauthredir' % self.name] = callback
             url = client.prepare_request_uri(
                 self.expand_url(self.authorize_url),
                 redirect_uri=callback,
                 scope=scope,
+                state=state,
                 **params
             )
         return redirect(url)
@@ -533,7 +551,9 @@ class OAuthRemoteApp(object):
             _encode(self.access_token_method)
         )
 
-        resp, content = self.http_request(uri, headers, data)
+        resp, content = self.http_request(
+            uri, headers, to_bytes(data, self.encoding)
+        )
         data = parse_response(resp, content)
         if resp.code not in (200, 201):
             raise OAuthException(
@@ -557,7 +577,7 @@ class OAuthRemoteApp(object):
             body = client.prepare_request_body(**remote_args)
             resp, content = self.http_request(
                 self.expand_url(self.access_token_url),
-                data=body,
+                data=to_bytes(body, self.encoding),
                 method=self.access_token_method,
             )
         elif self.access_token_method == 'GET':
