@@ -8,6 +8,7 @@
     :copyright: (c) 2013 by Hsiaoming Yang.
 """
 
+import logging
 from functools import wraps
 from werkzeug import cached_property
 from flask import request, redirect, url_for
@@ -17,12 +18,14 @@ from oauthlib.oauth1 import WebApplicationServer as Server
 from oauthlib.oauth1 import SIGNATURE_HMAC, SIGNATURE_RSA
 from oauthlib.common import to_unicode, add_params_to_uri
 from oauthlib.oauth1.rfc5849 import errors
-from ..utils import log, extract_params, create_response
+from ..utils import extract_params, create_response
 
 SIGNATURE_METHODS = (SIGNATURE_HMAC, SIGNATURE_RSA)
 
 __all__ = ('OAuth1Provider', 'OAuth1RequestValidator')
 
+log = logging.getLogger('flask_oauthlib')
+
 
 class OAuth1Provider(object):
     """Provide secure services using OAuth1.
@@ -725,12 +728,12 @@ class OAuth1RequestValidator(RequestValidator):
                                      access_token=None):
         """Validate the timestamp and nonce is used or not."""
         log.debug('Validate timestamp and nonce %r', client_key)
-        nonce = self._noncegetter(
+        nonce_exists = self._noncegetter(
             client_key=client_key, timestamp=timestamp,
             nonce=nonce, request_token=request_token,
             access_token=access_token
         )
-        if nonce:
+        if nonce_exists:
             return False
         self._noncesetter(
             client_key=client_key, timestamp=timestamp,
